@@ -136,7 +136,7 @@ namespace Breeze
         if( _enabled != value )
         {
             _enabled = value;
-            if( _enabled ) clearSplitter();
+            if( !_enabled ) clearSplitter();
         }
     }
 
@@ -338,11 +338,6 @@ namespace Breeze
         // release mouse
         if( mouseGrabber() == this ) releaseMouse();
 
-        // hide
-        parentWidget()->setUpdatesEnabled(false);
-        hide();
-        parentWidget()->setUpdatesEnabled(true);
-
         // send hover event
         if( _splitter )
         {
@@ -351,7 +346,6 @@ namespace Breeze
                 _splitter.data()->mapFromGlobal(QCursor::pos()), _hook);
             QCoreApplication::sendEvent( _splitter.data(), &hoverEvent );
             _splitter.clear();
-
         }
 
         // kill timer if any
@@ -361,6 +355,12 @@ namespace Breeze
             _timerId = 0;
         }
 
+        // hide
+        parentWidget()->setUpdatesEnabled(false);
+        // Note: This sends a synthetic mouse event to the widget below (to get focus), which might be
+        // another SplitterHandle, therefore enabling this SplitterProxy again!
+        hide();
+        parentWidget()->setUpdatesEnabled(true);
     }
 
 }
